@@ -249,10 +249,10 @@ class Dependency {
         }
         // PHP
         if (($project == '') && ($package == 'php')) {
-            return 'php5-common';
+            return 'php-common';
         }
         if (($project == '') && ($package == 'php-cli')) {
-            return 'php5-cli';
+            return 'php-cli';
         }
         // lib-*
         if (($project == '') && substr($package, 0, 4) == 'lib-') {
@@ -285,14 +285,18 @@ class Dependency {
         if (substr($project, 0, 5) == 'pear-') {
             $channel_url = substr($project, 5);
             if ($channel_url === 'pecl.php.net') {
-                $prefix = 'php5';
+                $prefix = 'php';
             }
             // Split channel url by dots
             $channel_components = explode(".", $channel_url);
             // Split package name by underscores
             $package_components = explode('_', $package);
             // Drop last part of url (TLD):
-            array_pop($channel_components);
+            $tld = array_pop($channel_components);
+            if (($tld === 'net') && (end($channel_components) === 'sourceforge')) {
+                // consider sourceforge.net as a TLD
+                array_pop($channel_components);
+            }
             // Drop first part of url if equal to pear, pecl or www
             if (isset($channel_components[0]) && in_array($channel_components[0], Array('pear', 'pecl', 'www'))) {
                 array_shift($channel_components);
@@ -306,7 +310,8 @@ class Dependency {
                 array_shift($package_components);
             }
             // PEAR: Build the debian name from remaining components
-            return implode('-', array_merge(Array($prefix), $channel_components, $package_components));
+            $all_components = array_merge(Array($prefix), $channel_components, $package_components);
+            return preg_replace('/[^a-zA-Z0-9.-]/', '-', implode('-', $all_components));
         }
         // Return package name if package name begins with project name
         if (strpos($package, $project) === 0) {
@@ -321,7 +326,8 @@ class Dependency {
             array_shift($package_components);
         }
         // Composer: Build the debian name from remaining components
-        return implode('-', array_merge(Array($prefix), $project_components, $package_components));
+        $all_components = array_merge(Array($prefix), $project_components, $package_components);
+        return preg_replace('/[^a-zA-Z0-9.-]/', '-', implode('-', $all_components));
     }
 
     /**
@@ -342,6 +348,9 @@ class Dependency {
         if (is_null($name)) {
             return NULL;
         }
+	if ($name == 'php-common') {
+	    return $name;
+	}
         if (!$this->minVersion && !$this->maxVersion) {
             return $name;
         }
